@@ -34,6 +34,7 @@ from .models import Component, ComponentType, ComponentVersion, ComponentVersion
 # to be callable only by other apps in the authoring package.
 __all__ = [
     "get_or_create_component_type",
+    "get_or_create_component_type_by_entity_key",
     "create_component",
     "create_component_version",
     "create_next_component_version",
@@ -73,6 +74,27 @@ def get_or_create_component_type(namespace: str, name: str) -> ComponentType:
     return component_type
 
 
+def get_or_create_component_type_by_entity_key(entity_key: str) -> tuple[ComponentType, str]:
+    """
+    Get or create a ComponentType based on a full entity key string.
+
+    The entity key is expected to be in the format
+    ``"{namespace}:{type_name}:{local_key}"``. This function will parse out the
+    ``namespace`` and ``type_name`` parts and use those to get or create the
+    ComponentType.
+
+    Raises ValueError if the entity_key is not in the expected format.
+    """
+    try:
+        namespace, type_name, local_key = entity_key.split(':', 2)
+    except ValueError as exc:
+        raise ValueError(
+            f"Invalid entity_key format: {entity_key!r}. "
+            "Expected format: '{namespace}:{type_name}:{local_key}'"
+        ) from exc
+    return get_or_create_component_type(namespace, type_name), local_key
+
+
 def create_component(
     learning_package_id: int,
     /,
@@ -137,10 +159,28 @@ def create_next_component_version(
     created: datetime,
     title: str | None = None,
     created_by: int | None = None,
+    *,
+    force_version_num: int | None = None,
+    ignore_previous_content: bool = False,
 ) -> ComponentVersion:
     """
     Create a new ComponentVersion based on the most recent version.
 
+    Args:
+        component_pk (int): The primary key of the Component to version.
+        content_to_replace (dict): Mapping of file keys to Content IDs,
+            None (for deletion), or bytes (for new file content).
+        created (datetime): The creation timestamp for the new version.
+        title (str, optional): Title for the new version. If None, uses the previous version's title.
+        created_by (int, optional): User ID of the creator.
+        force_version_num (int, optional): If provided, overrides the automatic version number increment and sets
+            this version's number explicitly. Use this if you need to restore or import a version with a specific
+            version number, such as during data migration or when synchronizing with external systems.
+        ignore_previous_content (bool): If True, do not copy over content from the previous version.
+
+    Returns:
+        ComponentVersion: The newly created ComponentVersion instance.
+
     A very common pattern for making a new ComponentVersion is going to be "make
     it just like the last version, except changing these one or two things".
     Before calling this, you should create any new contents via the contents
@@ -161,6 +201,14 @@ def create_next_component_version(
     convenient to remove paths (e.g. due to deprecation) without having to
     always check for its existence first.
 
+    Why use force_version_num?
+        Normally, the version number is incremented automatically from the latest version. If you need to set a specific
+        version number (for example, when restoring from backup, importing legacy data, or synchronizing with another
+        system), use force_version_num to override the default behavior.
+
+    Why not use create_component_version?
+        The main reason is that we want to reuse the logic to create a static file component from a dictionary.
+
     TODO: Have to add learning_downloadable info to this when it comes time to
           support static asset download.
     """
@@ -180,6 +228,9 @@ def create_next_component_version(
         if title is None:
             title = last_version.title
 
+    if force_version_num is not None:
+        next_version_num = force_version_num
+
     with atomic():
         publishable_entity_version = publishing_api.create_publishable_entity_version(
             component_pk,
@@ -219,6 +270,10 @@ def create_next_component_version(
                     component_version=component_version,
                     key=key,
                 )
+
+        if ignore_previous_content:
+            return component_version
+
         # Now copy any old associations that existed, as long as they aren't
         # in conflict with the new stuff or marked for deletion.
         last_version_content_mapping = ComponentVersionContent.objects \
