@@ -10,7 +10,7 @@ from contextlib import nullcontext
 from dataclasses import dataclass
 from datetime import datetime, timezone
 from enum import Enum
-from typing import ContextManager, TypeVar
+from typing import ContextManager, Optional, TypeVar
 
 from django.core.exceptions import ObjectDoesNotExist, ValidationError
 from django.db.models import F, Q, QuerySet
@@ -58,6 +58,7 @@ __all__ = [
     "create_publishable_entity_version",
     "get_publishable_entity",
     "get_publishable_entity_by_key",
+    "get_publishable_entities",
     "get_last_publish",
     "get_all_drafts",
     "get_entities_with_unpublished_changes",
@@ -69,7 +70,7 @@ __all__ = [
     "set_draft_version",
     "soft_delete_draft",
     "reset_drafts_to_published",
-    "register_content_models",
+    "register_publishable_models",
     "filter_publishable_entities",
     # 🛑 UNSTABLE: All APIs related to containers are unstable until we've figured
     #              out our approach to dynamic content (randomized, A/B tests, etc.)
@@ -88,6 +89,7 @@ __all__ = [
     "get_containers_with_entity",
     "get_container_children_count",
     "bulk_draft_changes_for",
+    "get_container_children_entities_keys",
 ]
 
 
@@ -261,6 +263,20 @@ def get_all_drafts(learning_package_id: int, /) -> QuerySet[Draft]:
     )
 
 
+def get_publishable_entities(learning_package_id: int, /) -> QuerySet[PublishableEntity]:
+    """
+    Get all entities in a learning package.
+    """
+    return (
+        PublishableEntity.objects
+        .filter(learning_package_id=learning_package_id)
+        .select_related(
+            "draft__version",
+            "published__version",
+        )
+    )
+
+
 def get_entities_with_unpublished_changes(
     learning_package_id: int,
     /,
@@ -417,15 +433,22 @@ def publish_from_drafts(
     return publish_log
 
 
-def get_draft_version(publishable_entity_id: int, /) -> PublishableEntityVersion | None:
+def get_draft_version(publishable_entity_or_id: PublishableEntity | int, /) -> PublishableEntityVersion | None:
     """
     Return current draft PublishableEntityVersion for this PublishableEntity.
 
     This function will return None if there is no current draft.
     """
+    if isinstance(publishable_entity_or_id, PublishableEntity):
+        # Fetches the draft version for a given PublishableEntity.
+        # Gracefully handles cases where no draft is present.
+        draft: Optional[Draft] = getattr(publishable_entity_or_id, "draft", None)
+        if draft is None:
+            return None
+        return draft.version
     try:
         draft = Draft.objects.select_related("version").get(
-            entity_id=publishable_entity_id
+            entity_id=publishable_entity_or_id
         )
     except Draft.DoesNotExist:
         # No draft was ever created.
@@ -437,15 +460,22 @@ def get_draft_version(publishable_entity_id: int, /) -> PublishableEntityVersion
     return draft.version
 
 
-def get_published_version(publishable_entity_id: int, /) -> PublishableEntityVersion | None:
+def get_published_version(publishable_entity_or_id: PublishableEntity | int, /) -> PublishableEntityVersion | None:
     """
     Return current published PublishableEntityVersion for this PublishableEntity.
 
     This function will return None if there is no current published version.
     """
+    if isinstance(publishable_entity_or_id, PublishableEntity):
+        # Fetches the published version for a given PublishableEntity.
+        # Gracefully handles cases where no published version is present.
+        published: Optional[Published] = getattr(publishable_entity_or_id, "published", None)
+        if published is None:
+            return None
+        return published.version
     try:
         published = Published.objects.select_related("version").get(
-            entity_id=publishable_entity_id
+            entity_id=publishable_entity_or_id
         )
     except Published.DoesNotExist:
         return None
@@ -789,7 +819,7 @@ def reset_drafts_to_published(
             set_draft_version(draft, published_version_id)
 
 
-def register_content_models(
+def register_publishable_models(
     content_model_cls: type[PublishableEntityMixin],
     content_version_model_cls: type[PublishableEntityVersionMixin],
 ) -> PublishableContentModelRegistry:
@@ -805,10 +835,10 @@ def register_content_models(
     method. For example, in the components app, this looks like:
 
         def ready(self):
-            from ..publishing.api import register_content_models
+            from ..publishing.api import register_publishable_models
             from .models import Component, ComponentVersion
 
-            register_content_models(Component, ComponentVersion)
+            register_publishable_models(Component, ComponentVersion)
 
     There may be a more clever way to introspect this information from the model
     metadata, but this is simple and explicit.
@@ -1112,6 +1142,7 @@ def create_next_container_version(
     created_by: int | None,
     container_version_cls: type[ContainerVersionModel] = ContainerVersion,  # type: ignore[assignment]
     entities_action: ChildrenEntitiesAction = ChildrenEntitiesAction.REPLACE,
+    force_version_num: int | None = None,
 ) -> ContainerVersionModel:
     """
     [ 🛑 UNSTABLE ]
@@ -1132,26 +1163,40 @@ def create_next_container_version(
         created: The date and time the container version was created.
         created_by: The ID of the user who created the container version.
         container_version_cls: The subclass of ContainerVersion to use, if applicable.
+        force_version_num (int, optional): If provided, overrides the automatic version number increment and sets
+            this version's number explicitly. Use this if you need to restore or import a version with a specific
+            version number, such as during data migration or when synchronizing with external systems.
 
     Returns:
         The newly created container version.
+
+    Why use force_version_num?
+        Normally, the version number is incremented automatically from the latest version.
+        If you need to set a specific version number (for example, when restoring from backup,
+        importing legacy data, or synchronizing with another system),
+        use force_version_num to override the default behavior.
     """
     assert issubclass(container_version_cls, ContainerVersion)
     with atomic():
         container = Container.objects.select_related("publishable_entity").get(pk=container_pk)
         entity = container.publishable_entity
         last_version = container.versioning.latest
-        assert last_version is not None
-        next_version_num = last_version.version_num + 1
+        if last_version is None:
+            next_version_num = 1
+        else:
+            next_version_num = last_version.version_num + 1
 
-        if entity_rows is None:
+        if force_version_num is not None:
+            next_version_num = force_version_num
+
+        if entity_rows is None and last_version is not None:
             # We're only changing metadata. Keep the same entity list.
             next_entity_list = last_version.entity_list
         else:
             next_entity_list = create_next_entity_list(
                 entity.learning_package_id,
                 last_version,
-                entity_rows,
+                entity_rows if entity_rows is not None else [],
                 entities_action
             )
 
@@ -1275,6 +1320,7 @@ def get_entities_in_container(
     container: Container,
     *,
     published: bool,
+    select_related_version: str | None = None,
 ) -> list[ContainerEntityListEntry]:
     """
     [ 🛑 UNSTABLE ]
@@ -1285,14 +1331,35 @@ def get_entities_in_container(
         container: The Container, e.g. returned by `get_container()`
         published: `True` if we want the published version of the container, or
             `False` for the draft version.
+        select_related_version: An optional optimization; specify a relationship
+        on ContainerVersion, like `componentversion` or `containerversion__x`
+        to preload via select_related.
     """
     assert isinstance(container, Container)
-    container_version = container.versioning.published if published else container.versioning.draft
+    if published:
+        # Very minor optimization: reload the container with related 1:1 entities
+        container = Container.objects.select_related(
+            "publishable_entity__published__version__containerversion__entity_list").get(pk=container.pk)
+        container_version = container.versioning.published
+        select_related = ["entity__published__version"]
+        if select_related_version:
+            select_related.append(f"entity__published__version__{select_related_version}")
+    else:
+        # Very minor optimization: reload the container with related 1:1 entities
+        container = Container.objects.select_related(
+            "publishable_entity__draft__version__containerversion__entity_list").get(pk=container.pk)
+        container_version = container.versioning.draft
+        select_related = ["entity__draft__version"]
+        if select_related_version:
+            select_related.append(f"entity__draft__version__{select_related_version}")
     if container_version is None:
         raise ContainerVersion.DoesNotExist  # This container has not been published yet, or has been deleted.
     assert isinstance(container_version, ContainerVersion)
-    entity_list = []
-    for row in container_version.entity_list.entitylistrow_set.order_by("order_num"):
+    entity_list: list[ContainerEntityListEntry] = []
+    for row in container_version.entity_list.entitylistrow_set.select_related(
+        "entity_version",
+        *select_related,
+    ).order_by("order_num"):
         entity_version = row.entity_version  # This will be set if pinned
         if not entity_version:  # If this entity is "unpinned", use the latest published/draft version:
             entity_version = row.entity.published.version if published else row.entity.draft.version
@@ -1385,7 +1452,10 @@ def get_containers_with_entity(
         qs = Container.objects.filter(
             publishable_entity__draft__version__containerversion__entity_list__entitylistrow__entity_id=publishable_entity_pk,  # pylint: disable=line-too-long # noqa: E501
         )
-    return qs.order_by("pk").distinct()  # Ordering is mostly for consistent test cases.
+    return qs.select_related(
+        "publishable_entity__draft__version__containerversion",
+        "publishable_entity__published__version__containerversion",
+    ).order_by("pk").distinct()  # Ordering is mostly for consistent test cases.
 
 
 def get_container_children_count(
@@ -1414,6 +1484,22 @@ def get_container_children_count(
     return container_version.entity_list.entitylistrow_set.filter(**filter_deleted).count()
 
 
+def get_container_children_entities_keys(container_version: ContainerVersion) -> list[str]:
+    """
+    Fetch the list of entity keys for all entities in the given container version.
+
+    Args:
+        container_version: The ContainerVersion to fetch the entity keys for.
+    Returns:
+        A list of entity keys for all entities in the container version, ordered by entity key.
+    """
+    return list(
+        container_version.entity_list.entitylistrow_set
+        .values_list("entity__key", flat=True)
+        .order_by("order_num")
+    )
+
+
 def bulk_draft_changes_for(
     learning_package_id: int,
     changed_by: int | None = None,
